@@ -50,9 +50,15 @@ class Mapping:
             if not oproduct.mapping:
                 oproduct.mapping = self.catalog.find_by_id(oproduct.sku)
         if not all([x.mapping for x in self.orders.all_products]):
-            logger.error(f"Products {','.join([x.name for x in self.orders.all_products if not x.mapping])} not found in catalog, skipping products!")
-        if not all([x.mapping.price == x.price for x in self.orders.all_products if x.mapping]):
-            logger.error(f"Products {','.join([x.name for x in self.orders.all_products if x.mapping.price != x.price])} do not have matching prices!")
+            logger.error(
+                f"Products {','.join([x.name for x in self.orders.all_products if not x.mapping])} not found in catalog, skipping products!"
+            )
+        if not all(
+            [x.mapping.price == x.price for x in self.orders.all_products if x.mapping]
+        ):
+            logger.error(
+                f"Products {','.join([x.name for x in self.orders.all_products if x.mapping.price != x.price])} do not have matching prices!"
+            )
             sys.exit(1)
 
     def confirm(self) -> None:
@@ -66,7 +72,9 @@ class Mapping:
             )
             for i, order_prod in enumerate(self.orders.unique_products):
                 if not order_prod.mapping:
-                    logger.error(f"Product {order_prod.name} not found in catalog, skipping in all orders!")
+                    logger.error(
+                        f"Product {order_prod.name} not found in catalog, skipping in all orders!"
+                    )
                     continue
                 tbl.add_row(
                     str(i),
